# Neural Network Functionals

::: warpconvnet.nn.functional

## Functionals

### Sparse convolution

::: warpconvnet.nn.functional.sparse_conv

### Sparse depthwise convolution

::: warpconvnet.nn.functional.sparse_conv_depth

### Sparse pooling

::: warpconvnet.nn.functional.sparse_pool

### Sparse ops helpers

::: warpconvnet.nn.functional.sparse_ops

### Point pooling

::: warpconvnet.nn.functional.point_pool

### Point unpooling

::: warpconvnet.nn.functional.point_unpool

### Grid convolution

::: warpconvnet.nn.functional.grid_conv

### Factor grid

::: warpconvnet.nn.functional.factor_grid

### Global pooling

::: warpconvnet.nn.functional.global_pool

### Feature transforms

::: warpconvnet.nn.functional.transforms

### Encodings

::: warpconvnet.nn.functional.encodings

### Normalizations

::: warpconvnet.nn.functional.normalizations

### Segmented arithmetic

::: warpconvnet.nn.functional.segmented_arithmetics

### Batched matrix multiplication

::: warpconvnet.nn.functional.bmm
